@@ -200,9 +200,14 @@ extern int errno;
 #endif
 
 #ifdef LINUX
+#ifdef __GLIBC__
+# include <net/route.h>
+# include <netinet/in.h>
+#else
 # include <linux/route.h>
 # include <linux/in.h>
 #endif
+#endif
 
 #ifndef HAVE_STRDUP
 char *strdup();
@@ -240,7 +245,7 @@ char *strdup();
 /* This is the only place you ever need to edit anything           */
 /*******************************************************************/
 
-#define clssattr 29         /* increase this for each new class added */
+#define clssattr 30         /* increase this for each new class added */
                             /* It defines the array size for class data */
 #define attrdim 3           /* Only used in CLASSATTRUBUTES[][] defn */
 
@@ -336,7 +341,6 @@ char *strdup();
 /*******************************************************************/
 
 #define CFENGINE_SERVICE "cfengine"
-#define CF_TIMEOUT 3
 
 #define CF_WORDSIZE 8 /* Number of bytes in a word */
 
@@ -393,6 +397,12 @@ struct cfdirent
 
 struct cfdirent *cfreaddir();
 
+enum cfsizes
+   {
+   cfabs,
+   cfpercent
+   };
+
 /*******************************************************************/
 /* These are to reuse some of the GLOBAL buffers used in parsing   */
 /*******************************************************************/
@@ -467,6 +477,8 @@ enum classes
    nextstep,
    crayos,
    GnU,
+   cfnt,
+   unix_sv,
    unused1,
    unused2,
    unused3
@@ -564,6 +576,8 @@ enum vnames
    cfaccess,
    cfclass,
    cfarch,
+   cfdate,
+   cfyear,
    cfallclass,
    cfexcludecp,
    cfexcludeln,
@@ -711,7 +725,8 @@ enum editnames
    SplitOn,
    AppendToLineIfNotContains,
    DeleteLinesAfterThisMatching,
-   DefineClasses
+   DefineClasses,
+   CatchAbort
    };
 
 enum editnames EditActionsToCode();
