@@ -40,6 +40,7 @@ extern char *VPRECONFIG;
 extern char *VRCFILE;
 
 extern char VARCH[];
+extern char VYEAR[];
 extern char *ACTIONTEXT[]; 
 extern char *ACTIONID[];
 extern char *CLASSTEXT[];
@@ -69,6 +70,7 @@ extern struct tm TM2;
 extern int ERRORCOUNT;
 extern int NUMBEROFEDITS;
 extern time_t CFSTARTTIME;
+extern int CF_TIMEOUT;
 
 extern struct utsname VSYSNAME;
 
@@ -108,7 +110,7 @@ extern char   IMAGEACTION[bufsize];
 extern char *HASH[hashtablesize];
 
 extern char VBUFF[bufsize];
-extern char OUTPUT[bufsize];
+extern char OUTPUT[bufsize*2];
 
 extern char VFACULTY[maxvarsize];
 extern char VDOMAIN[maxvarsize];
