@@ -108,7 +108,7 @@ char **argv;
 umask(0);
 
 strcpy(VINPUTFILE,CFD_INPUT);
-
+ 
 ISCFENGINE = false;   /* Switch for the parser */
 PARSEONLY  = false;
 
@@ -163,9 +163,8 @@ while ((c=getopt_long(argc,argv,"d:f:vhpFV",CFDOPTIONS,&optindex)) != EOF)
 
 LOGGING = true;                    /* Do output to syslog */
  
-sprintf(VBUFF,"%s/test",LOCKFILEDIR);
 sprintf(VPREFIX,"cfd:%s:",VUQNAME); 
-
+sprintf(VBUFF,"%s/test",LOCKFILEDIR);
 MakeDirectoriesFor(VBUFF);
 strcpy(VLOCKDIR,LOCKFILEDIR);
 
@@ -177,6 +176,7 @@ strcpy(VLOGDIR,LOGFILEDIR);
 strcpy(VDOMAIN,"undefined.domain");
 
 strcpy(VCANONICALFILE,CanonifyName(VINPUTFILE));
+ 
 }
 
 /*******************************************************************/
@@ -186,7 +186,12 @@ CheckVariables()
 { struct stat statbuf;
   int i, value = -1;
 
-bzero(CHECKSUMDB,bufsize);
+if ((CFDSTARTTIME = time((time_t *)NULL)) == -1)
+   {
+   printf("Couldn't read system clock\n");
+   }
+
+ bzero(CHECKSUMDB,bufsize);
 
 if (GetMacroValue("ChecksumDatabase"))
    {
@@ -338,9 +343,9 @@ openlog(VPREFIX,LOG_PID|LOG_NOWAIT|LOG_ODELAY,LOG_DAEMON);
   
 if ((!NO_FORK) && (fork() != 0))
    {
-   sprintf(OUTPUT,"cfd: starting %s\n",ctime(&CFSTARTTIME));
+   sprintf(OUTPUT,"cfd: starting %s\n",ctime(&CFDSTARTTIME));
    CfLog(cfinform,OUTPUT,"");
-   return;
+   exit(0);
    }
 
 if (!NO_FORK)
@@ -420,8 +425,8 @@ while (true)
       while (!FinishedWithConnection(recvbuffer,sendbuffer,&conn))
          {
          }
-      
-      close (conn.sd_reply);
+
+      close(conn.sd_reply);
       Debug("End of session\n");
 
       CheckFileChanges(argc,argv,sd);
@@ -608,7 +613,7 @@ CfLog(cfinform,"Malformed protocol request\n","");
 
 if (send(conn->sd_reply,sendbuffer,strlen(sendbuffer)+1,0) == -1)
    {
-   CfLog(cferror,"","send");
+   CfLog(cferror,"Couldn't send","send");
    exit(1);
    }
 
@@ -625,12 +630,13 @@ char **argv;
 int sd;
 
 { struct stat newstat;
-  char filename[bufsize],line[bufsize], *sp, **argvtest;
+  char filename[bufsize],line[bufsize], *sp;
+  char arg[maxshellargs][bufsize];
   FILE *pp;
-
+  int i;
+  
 bzero(&newstat,sizeof(struct stat));
-
-filename[0] = '\0';
+bzero(filename,bufsize);
 
 if ((sp=getenv(CFINPUTSVAR)) != NULL)
    {
@@ -646,41 +652,49 @@ strcat(filename,VINPUTFILE);
 if (stat(filename,&newstat) == -1)
    {
    sprintf(OUTPUT,"Input file %s missing!\n",filename);
+   CfLog(cferror,OUTPUT,filename);
    return;
    }
 
-Debug("Checking file updates on %s \n",filename);
+Debug("Checking file updates on %s (%x/%x)\n",filename, newstat.st_ctime, CFDSTARTTIME);
 
-if (CFSTARTTIME < newstat.st_ctime)
+if (CFDSTARTTIME < newstat.st_ctime)
    {
-   sprintf(OUTPUT,"Restarting and rereading config files %s..\n",filename);
+   sprintf(OUTPUT,"Rereading config files %s..\n",filename);
    CfLog(cfinform,OUTPUT,"");
 
-   argvtest[0] = argv[0];
-   argvtest[1] = "-p";
-   argvtest[2] = NULL;
+   /* Free up memory */
    
-   if (execv(argv[0],argvtest) == -1)
+   for (i = 0; i < hashtablesize; i++)
       {
-      CfLog(cferror,"Unable to restart cfd process\n","execv");
-      return;
+      if (HASH[i] != NULL)
+	 {
+	 free(HASH[i]);
+	 HASH[i] = NULL;
+	 }
       }
 
-   close(sd);
+   DeleteItemList(VHEAP);
+   DeleteItemList(VNEGHEAP);
+   DeleteAuthList(VADMIT);
+   strcpy(VDOMAIN,"undefined.domain");
+   
+   VADMIT = VADMITTOP = NULL;
+   VHEAP = VNEGHEAP = NULL;
 
-   if (execv(argv[0],argv) == -1)
-      {
-      CfLog(cferror,"Unable to restart cfd process\n","execv");
-      }
+   AddClassToHeap("any");
+   GetNameInfo();
+   ParseInputFiles();
+   CheckVariables();
    }
 }
 
-
 /**************************************************************/
 
 void ExitCleanly()
 
 { int i;
+ 
 sprintf(OUTPUT,"Exit -- (waiting for threads), pid = %d\n",getpid());
 CfLog(cfinform,OUTPUT,"");
 closelog();
@@ -791,14 +805,14 @@ if (GetMacroValue("cfrunCommand") == NULL)
    
    if (send(conn->sd_reply,sendbuffer,bufsize,0) == -1)
       {
-      CfLog(cferror,"","send");
+      CfLog(cferror,"Couldn't send","send");
       }
    return;
    }
 
-for (sp = args; *sp != '\0'; sp++) /* Blank out -K */
+for (sp = args; *sp != '\0'; sp++) /* Blank out -K -f */
    {
-   if (strncmp(sp,"-K",2) == 0)
+   if ((strncmp(sp,"-K",2) == 0) || (strncmp(sp,"-f",2) == 0))
       {
       *sp = ' ';
       *(sp+1) = ' ';
@@ -810,6 +824,13 @@ for (sp = args; *sp != '\0'; sp++) /* Blank out -K */
 	 *(sp+i) = ' ';
 	 }
       }
+   else if (strncmp(sp,"--file",7) == 0)
+      {
+      for (i = 0; i < 7; i++)
+	 {
+	 *(sp+i) = ' ';
+	 }
+      }
    }
 
 if (!GetLock("cfd","exec",VIFELAPSED,VEXPIREAFTER,VUQNAME,CFSTARTTIME))
@@ -818,7 +839,7 @@ if (!GetLock("cfd","exec",VIFELAPSED,VEXPIREAFTER,VUQNAME,CFSTARTTIME))
 
    if (send(conn->sd_reply,sendbuffer,bufsize,0) == -1)
       {
-      CfLog(cferror,"","send");
+      CfLog(cferror,"Couldn't send","send");
       }
    
    return;
@@ -832,7 +853,7 @@ if (strlen(buffer)+strlen(args)+6 > bufsize)
 
    if (send(conn->sd_reply,sendbuffer,bufsize,0) == -1)
       {
-      CfLog(cferror,"","send");
+      CfLog(cferror,"Couldn't send","send");
       }
 
    ReleaseCurrentLock();
@@ -849,7 +870,7 @@ else
 
       if (send(conn->sd_reply,sendbuffer,bufsize,0) == -1)
          {
-         CfLog(cferror,"","send");
+         CfLog(cferror,"Coudn't send","send");
          }
       }
    }
@@ -868,7 +889,7 @@ if ((pp = cfpopen(buffer,"r")) == NULL)
 
    if (send(conn->sd_reply,sendbuffer,strlen(sendbuffer),0) == -1)
       {
-      CfLog(cferror,"","send");
+      CfLog(cferror,"Couldn't send","send");
       }
    ReleaseCurrentLock();
    return;
@@ -903,11 +924,11 @@ while (!feof(pp))
 	 
    if (print)
       {
-      sprintf(sendbuffer,"%s: %s\n",VSYSNAME.nodename,line);
+      sprintf(sendbuffer,"%s\n",line);
 
       if (send(conn->sd_reply,sendbuffer,strlen(sendbuffer),0) == -1)
          {
-         CfLog(cferror,"","send");
+         CfLog(cferror,"Couldn't send","send");
 	 fflush(pp);
 	 break;
          }
@@ -952,7 +973,7 @@ char buf[bufsize];
   char ipstring[maxvarsize], fqname[bufsize];
   char name1[bufsize], name2[bufsize], name3[bufsize];
   struct hostent *hp;
-  int len;
+  int len, aliases, found;
    
 Debug("Connecting host identifies itself as %s\n",buf);
 
@@ -993,7 +1014,9 @@ if (strcmp(name3,name2) != 0)
    CfLog(cfinform,OUTPUT,"");
    return false;
    }
-  
+
+Debug("Attempting to look up hostname %s\n",name1);
+ 
 if ((hp = gethostbyname(name1)) == NULL)
    {
    Verbose("cfd: Couldn't look up name %s\n",fqname);
@@ -1003,15 +1026,57 @@ if ((hp = gethostbyname(name1)) == NULL)
    return false;
    }
 
-raddr.sin_addr.s_addr = ((struct in_addr *)(hp->h_addr))->s_addr;
 
-if (strcmp(name2,ToLowerStr(inet_ntoa(raddr.sin_addr))) != 0)
+Debug("Attempting to look up hostname %s\n",name1);
+ 
+if ((hp = gethostbyname(name1)) == NULL)
    {
-   sprintf(OUTPUT,"Reverse hostname lookup failed, host claiming to be %s was %s\n",buf,inet_ntoa(raddr.sin_addr));
-   CfLog(cfinform,OUTPUT,"");
+   Verbose("cfd: Couldn't look up name %s\n",fqname);
+   Verbose("     Make sure that fully qualified names can be looked up at your site!\n");
+   Verbose("     i.e. prep.ai.mit.edu, not just prep. If you use NIS or /etc/hosts\n");
+   Verbose("     make sure that the full form is registered too as an alias!\n");
    return false;
    }
 
+found = false;
+
+ /* On solaris machines, if you have nis first in nsswitch.conf you get
+    alias data in a weird format */
+ 
+ if (hp->h_aliases != NULL && hp->h_aliases[0] != NULL) 
+    {
+    for (aliases = 0; hp->h_aliases[aliases] != NULL; aliases++)
+       {
+       if (strcmp(name2,hp->h_aliases[aliases]) == 0)
+	  {
+	  found = true;
+	  break;
+	  }
+       }
+    }
+ 
+ if (! found )
+    {
+    for (aliases = 0; hp->h_addr_list[aliases] != NULL; aliases++)
+       {
+       char addr[16];
+       sprintf(addr,"%s",inet_ntoa(*(struct in_addr *)(hp->h_addr_list[aliases])));
+       
+       if (strcmp(name2,addr) == 0)
+	  {
+	  found = true;
+	  break;
+	  }
+       }
+    }
+ 
+ if (! found)
+    {
+    sprintf(OUTPUT,"Reverse hostname lookup failed, host claiming to be %s was %s\n",buf,inet_ntoa(raddr.sin_addr));
+    CfLog(cfinform,OUTPUT,"");
+    return false;
+    } 
+ 
 conn->hostname = strdup(name1);
 
 if (conn->hostname != NULL)
@@ -1037,7 +1102,7 @@ CfLog(cfinform,"Host authentication failed\n","");
 
 if (send(sd,sendbuffer,bufsize,0) == -1)
    {
-   CfLog(cferror,"","send");
+   CfLog(cferror,"Couldn't send","send");
    }
 }
 
@@ -1203,7 +1268,7 @@ if (strlen(filename) > maxlinksize)
 
    if (send(sd,sendbuffer,bufsize,0) == -1)
       {
-      CfLog(cferror,"","send");
+      CfLog(cferror,"Couldn't send","send");
       }
 
    return -1;
@@ -1216,7 +1281,7 @@ if (lstat(filename,&statbuf) == -1)
 
    if (send(sd,sendbuffer,bufsize,0) == -1)
       {
-      CfLog(cferror,"","send");
+      CfLog(cferror,"Couldn't send","send");
       }
 
    return -1;
@@ -1241,7 +1306,7 @@ if (S_ISLNK(statbuf.st_mode))
       
       if (send(sd,sendbuffer,bufsize,0) == -1)
 	 {
-	 CfLog(cferror,"","send");
+	 CfLog(cferror,"Couldn't send","send");
 	 }
       
       return -1;
@@ -1343,7 +1408,7 @@ sprintf(sendbuffer,"OK: %d %d %d %d %d %d %d %d %d %d %d %d",
 
 if (send(sd,sendbuffer,bufsize,0) == -1)
    {
-   CfLog(cferror,"","send");
+   CfLog(cferror,"Couldn't send","send");
    exit(1);
    }
 
@@ -1362,7 +1427,7 @@ else
 
 if (send(sd,sendbuffer,bufsize,0) == -1)
    {
-   CfLog(cferror,"","send");
+   CfLog(cferror,"Couldn't send","send");
    exit(1);
    }
 
@@ -1394,7 +1459,7 @@ for (i = 0; i < 16; i++)
    sscanf(sp,"%s",num);
 
    digest1[i] = (char) atoi(num);
-   sp += strlen((const char *)num) + 1;
+   sp += strlen((char *)num) + 1;
    }
 
 digest2[16] = '\0'; /* for libdb */
