@@ -58,7 +58,7 @@ CheckOptsAndInit(argc,argv);
 
 for (ip = VCFRUNHOSTLIST; ip != NULL; ip=ip->next)
    {
-   printf("cfrun: negotiating with %s\n",ip->name);
+   printf("cfrun: (%s)\n",ip->name);
    ConnectToServer(ip->name,ip->classes);
    }
 }
@@ -73,6 +73,7 @@ int argc;
 char **argv;
 
 { char buffer[maxvarsize], options[bufsize], line[bufsize], filename[bufsize], *sp;
+  char id[maxvarsize]; 
   struct Item *ip;
   FILE *fp;
   char ch;
@@ -112,6 +113,21 @@ while (!feof(fp))
       continue;
       }
 
+   if (strncmp(line,"access",6) == 0)
+      {
+      for (sp = line; (*sp != '=') && (*sp != '\0'); sp++)
+	 {
+	 }
+
+      if (*sp == '\0' || *(++sp) == '\0')
+	 {
+	 continue;
+	 }
+
+      CheckAccess(sp);
+      continue;
+      }
+
    sscanf(line,"%s %[^#\n]",buffer,options);
 
    if (buffer[0] == '#')
@@ -255,7 +271,7 @@ alarm(CF_TIMEOUT);
 
 if (err=connect(sd,(void *) &cin,sizeof(cin)) == -1)
    {
-   printf("Host %s isn't talking to anyone\n",host);
+   printf("Host %s isn't talking to anyone\n\n",host);
    return false;
    }
 
@@ -309,7 +325,14 @@ while (true)
       return true;;
       }
 
-   if ((strcmp(recvbuffer,CFD_TERMINATOR) == 0) || (n_read == 0))
+   if ((sp = strstr(recvbuffer,CFD_TERMINATOR)) != NULL)
+      {
+      *sp = '\0';
+      printf("%s\n",recvbuffer);
+      break;
+      }
+
+   if (n_read == 0)
       {
       break;
       }
@@ -401,6 +424,58 @@ if (send(sd,sendbuffer,bufsize,0) == -1)
    }
 }
 
+/********************************************************************/
+
+CheckAccess(users)
+
+char *users;
+
+{ char id[maxvarsize], *sp;
+  struct passwd *pw;
+  int uid, myuid;
+
+myuid = getuid();
+
+if (myuid == 0)
+   {
+   return;
+   }
+
+for (sp = users; *sp != '\0'; sp++)
+   {
+   id[0] = '\0';
+
+   sscanf(sp,"%[^,:]",id);
+
+   sp += strlen(id);
+   
+   if (isalpha(id[0]))
+      {
+      if ((pw = getpwnam(id)) == NULL)
+	 {
+	 printf("cfrun: No such user (%s) in password database\n",id);
+	 exit(0);
+	 }
+      
+      if (pw->pw_uid == myuid)
+	 {
+	 return;
+	 }
+      }
+   else
+      {
+      if (uid == myuid)
+	 {
+	 return;
+	 }
+      }
+   }
+
+ printf("cfrun: you have not been granted permission to run cfrun\n");
+ exit(0);
+}
+
+
 /********************************************************************/
 /* Toolkit                                                          */
 /********************************************************************/
