@@ -65,6 +65,7 @@ char *CLASSTEXT[] =   /* If you change here change enum classes too! */
    "cray",
    "gnu",
    "nt",
+   "unix_sv",
    "unused1",
    "unused2",
    "unused3",
@@ -102,6 +103,7 @@ char *CLASSATTRIBUTES[clssattr][attrdim] =
    "sn*","cray*","*",          /* cray */
    "gnu*","*","*",             /* gnu */
    "Windows_NT","*","*",       /* NT */
+   "unix_sv","*","*",          /* Unixware */
    "unused1","blah","blah",
    "unused2","blah","blah",
    "unused3","blah","blah",
@@ -137,6 +139,7 @@ char *VPSCOMM[clssattr] =
    "/bin/ps",       /* cray */
    "/bin/ps",       /* gnu */
    "/C/usr/bin/ps", /* NT */
+   "/bin/ps",       /* unixware */
    "/bin/ps",
    "/bin/ps",
    "/bin/ps",
@@ -172,6 +175,7 @@ char *VPSOPTS[clssattr] =
    "-ef",    /* cray */
    "-ax",    /* gnu */
    "-a",     /* NT */
+   "-ef",    /* Unixware */
    "-",
    "-",
    "-",
@@ -207,6 +211,7 @@ char *VMOUNTCOMM[clssattr] =
    "/etc/mount -va",      /* cray */
    "/bin/mount -va",      /* gnu */
    "N/A",                 /* NT */
+   "/sbin/mountall",      /* Unixware */
    "unused-blah",
    "unused-blah",
    "unused-blah",
@@ -242,6 +247,7 @@ char *VUNMOUNTCOMM[clssattr] =
    "/etc/umount",      /* cray */
    "/sbin/umount",     /* gnu */
    "N/A",              /* NT */
+   "/sbin/umount",     /* Unixware */
    "unused-blah",
    "unused-blah",
    "unused-blah",
@@ -279,6 +285,7 @@ char *VMOUNTOPTS[clssattr] =
    "bg,hard,intr",    /* cray */
    "defaults",        /* gnu */
    "N/A",             /* NT */
+   "bg,hard,intr",    /* Unixware */
    "unused-blah",
    "unused-blah",
    "unused-blah",
@@ -314,6 +321,7 @@ char *VIFDEV[clssattr] =
    "en0",    /* cray */
    "eth0",   /* gnu */
    "N/A",    /* NT */
+   "unknown", /* Unixware */
    "unused-blah",
    "unused-blah",
    "unused-blah",
@@ -350,6 +358,7 @@ char *VRESOLVCONF[clssattr] =
    "/etc/resolv.conf",     /* cray */
    "/etc/resolv.conf",     /* gnu */
    "/C/resolv.conf",       /* NT */
+   "/etc/resolv.conf",     /* Unixware */
    "unused-blah",
    "unused-blah",
    "unused-blah",
@@ -387,6 +396,7 @@ char *VFSTAB[clssattr] =
    "/etc/fstab",       /* cray */
    "/etc/fstab",       /* gnu */
    "N/A",              /* NT */
+   "/etc/vfstab",      /* Unixware */
    "unused-blah",
    "unused-blah",
    "unused-blah",
@@ -422,6 +432,7 @@ char *VMAILDIR[clssattr] =
    "/usr/mail",          /* cray */
    "/var/spool/mail",    /* gnu */
    "N/A",                /* NT */
+   "/var/mail",          /* Unixware */
    "unused-blah",
    "unused-blah",
    "unused-blah",
@@ -456,7 +467,8 @@ char *VNETSTAT[clssattr] =
    "/usr/ucb/netstat -rn",   /* nextstep */
    "/usr/ucb/netstat -rn",   /* cray */
    "/bin/netstat -rn",       /* gnu */
-   "/C/WINNT/System32/netstat" /* NT */
+   "/C/WINNT/System32/netstat", /* NT */
+   "/usr/bin/netstat -rn",   /* Unixware */
    "unused-blah",
    "unused-blah",
    "unused-blah",
