@@ -486,10 +486,8 @@ else
    close(sd);
    return false;
    }
-
-
-close(sd);
-return false;
+ 
+/* Not reached */
 }
 
 /*********************************************************************/
@@ -533,7 +531,7 @@ alarm(CF_TIMEOUT);
 
 if (err = connect(sd,(void *) &cin,sizeof(cin)) == -1)
    {
-   sprintf("Couldn't connect to host %s\n",ip->server);
+   sprintf(OUTPUT,"Couldn't connect to host %s\n",ip->server);
    CfLog(cferror,OUTPUT,"connect");
    close(sd);
    close(dd);
