@@ -148,7 +148,7 @@ char *filename;
    /* Many of the functions called here are defined in the */
    /* item.c toolkit since they operate on linked lists    */
 
-{ struct Edlist *ep, *loopstart, *loopend;
+{ struct Edlist *ep, *loopstart, *loopend, *ThrowAbort();
   struct Item *filestart = NULL, *newlineptr;
   char *currenteditscript, *searchstr;
   struct stat tmpstat;
@@ -220,9 +220,13 @@ while (ep != NULL)
       case AutoCreate:
                break;
 
+      case CatchAbort:
+	          EditVerbose("%s: Caught Exception\n",VPREFIX);
+	          break;
+
       case SplitOn:
 	          spliton = *(ep->data);
-		  EditVerbose("Split lines by %c\n",spliton);
+		  EditVerbose("%s: Split lines by %c\n",VPREFIX,spliton);
 		  break;
 
       case DeleteLinesStarting:
@@ -239,15 +243,17 @@ while (ep != NULL)
 
       case DeleteLinesAfterThisMatching:
 
-	       if (CURRENTLINEPTR != filestart)
+               if ((filestart == NULL) || (CURRENTLINEPTR == NULL))
+		  {
+		  break;
+		  }
+	       else if (CURRENTLINEPTR->next != NULL)
 		  {
                   while (DeleteItemMatching(&(CURRENTLINEPTR->next),ep->data))
                     {
 	   	    }
-
-		  CURRENTLINEPTR->next = NULL;
-	          break;
 		  }
+               break;	       
 
       case DeleteLinesMatching:
                while (DeleteItemMatching(&filestart,ep->data))
@@ -268,14 +274,15 @@ while (ep != NULL)
 
       case SetLine:
                strcpy(ACTIONBUFF,ep->data);
-               EditVerbose("Set current line to %s\n",ACTIONBUFF);
+               EditVerbose("%s: Set current line to %s\n",VPREFIX,ACTIONBUFF);
                break;
 
       case AppendIfNoLineMatching:
 
                if (strcmp(ACTIONBUFF,"") == 0)
                   {
-                  printf("%s: SetLine not set when calling AppendIfNoLineMatching %s\n",VPREFIX,ep->data);
+                  sprintf(OUTPUT,"%s: SetLine not set when calling AppendIfNoLineMatching %s\n",VPREFIX,ep->data);
+		  CfLog(cferror,OUTPUT,"");
                   continue;
                   }
 	       
@@ -453,7 +460,7 @@ while (ep != NULL)
                if (newlineptr == NULL)
                   {
                   EditVerbose("%s: LocateLineMatchingRegexp failed in %s, aborting editing\n",VPREFIX,filename);
-                  goto abort;
+                  ep = ThrowAbort(ep);
                   }
                break;
 
@@ -469,7 +476,7 @@ while (ep != NULL)
                if (! IncrementEditPointer(ep->data,filestart))     /* edittools */
                   {
                   printf ("%s: IncrementPointer failed in %s, aborting editing\n",VPREFIX,filename);
-  	          goto abort;
+  	          ep = ThrowAbort(ep);
                   }
 
                break;
@@ -487,7 +494,7 @@ while (ep != NULL)
                   {
                   EditVerbose("%s: Nothing matched DeleteToLineMatching regular expression\n",VPREFIX);
                   EditVerbose("%s: Aborting file editing of %s.\n",VPREFIX ,filename);
-                  goto abort;
+                  ep = ThrowAbort(ep);
                   }
                break;
 
@@ -496,7 +503,7 @@ while (ep != NULL)
                   {
                   EditVerbose("%s: Could not delete %s lines from file\n",VPREFIX,ep->data);
                   EditVerbose("%s: Aborting file editing of %s.\n",VPREFIX,filename);
-                  goto abort;
+                  ep = ThrowAbort(ep);
                   }
                break;
 
@@ -505,7 +512,7 @@ while (ep != NULL)
                   {
                   EditVerbose("%s: Nothing matched HashCommentToLineMatching regular expression\n",VPREFIX);
                   EditVerbose("%s: Aborting file editing of %s.\n",VPREFIX,filename);
-                  goto abort;
+                  ep = ThrowAbort(ep);
                   }
                break;
 
@@ -514,7 +521,7 @@ while (ep != NULL)
                   {
                   EditVerbose("%s: Nothing matched PercentCommentToLineMatching regular expression\n",VPREFIX);
                   EditVerbose("%s: Aborting file editing of %s.\n",VPREFIX,filename);
-                  goto abort;
+                  ep = ThrowAbort(ep);
                   }
                break;
 
@@ -523,7 +530,7 @@ while (ep != NULL)
                   {
                   EditVerbose("%s: Nothing matched CommentToLineMatching regular expression\n",VPREFIX);
                   EditVerbose("%s: Aborting file editing of %s.\n",VPREFIX,filename);
-                  goto abort;
+                  ep = ThrowAbort(ep);
                   }
                break;
 
@@ -532,7 +539,7 @@ while (ep != NULL)
                   {
                   EditVerbose("%s: Could not comment %s lines from file\n",VPREFIX,ep->data);
                   EditVerbose("%s: Aborting file editing of %s.\n",VPREFIX,filename);
-                  goto abort;
+                  ep = ThrowAbort(ep);
                   }
                break;
 	       
@@ -541,7 +548,7 @@ while (ep != NULL)
                   {
                   EditVerbose("%s: Could not comment %s lines from file\n",VPREFIX,ep->data);
                   EditVerbose("%s: Aborting file editing of %s.\n",VPREFIX,filename);
-                  goto abort;
+                  ep = ThrowAbort(ep);
                   }
                break;
 
@@ -565,7 +572,7 @@ while (ep != NULL)
                if (! RunEditScript(ep->data,filename,&filestart))
                   {
                   printf("%s: Aborting further edits to %s\n",VPREFIX,filename);
-                  goto abort;
+                  ep = ThrowAbort(ep);
                   }
                break;
 
@@ -575,7 +582,7 @@ while (ep != NULL)
                   if (! RunEditScript(currenteditscript,filename,&filestart))
                      {
                      printf("%s: Aborting further edits to %s\n",VPREFIX,filename);
-                     goto abort;
+                     ep = ThrowAbort(ep);
                      }
                   }
                break;
@@ -586,7 +593,7 @@ while (ep != NULL)
                   if (! RunEditScript(currenteditscript,filename,&filestart))
                      {
                      printf("%s: Aborting further edits to %s\n",VPREFIX,filename);
-                     goto abort;
+                     ep = ThrowAbort(ep);
                      }
                   }
                break;
@@ -1197,3 +1204,24 @@ for (sp = ep->data; *sp != '\0'; sp++)
    AddClassToHeap(currentitem);
    }
 }
+
+/**************************************************************/
+
+struct Edlist *ThrowAbort(from)
+
+struct Edlist *from;
+
+{ struct Edlist *ep, *last;
+ 
+for (ep = from; ep != NULL; ep=ep->next)
+   {
+   if (ep->code == CatchAbort)
+      {
+      return ep;
+      }
+   
+   last = ep;
+   }
+
+return last; 
+}
