@@ -114,7 +114,7 @@ char *classlist;
 
 { char *sp, currentitem[maxvarsize];
 
-if (classlist == NULL)
+if ((classlist == NULL) || strlen(classlist) == 0)
    {
    return;
    }
@@ -215,6 +215,8 @@ for (i = 0; i < 12; i++)
 
 /* Year */
 
+ strcpy(VYEAR,buf5); 
+
 sprintf(out,"Yr%s",buf5);
 AddClassToHeap(out);
 }
@@ -226,6 +228,7 @@ AddClassToHeap(class)
 char *class;
 
 {
+Debug("AddClassToHeap(%s)\n",class);
 if (IsItemIn(VHEAP,class))
    {
    return;
