@@ -476,7 +476,7 @@ switch (action)
                    {
                    if (chmod (file,newperm & 07777) == -1)
 		      {
-                      sprintf("chmod failed on %s\n",file);
+                      sprintf(OUTPUT,"chmod failed on %s\n",file);
                       CfLog(cferror,OUTPUT,"chmod");
                       break;
                       }
@@ -496,7 +496,7 @@ switch (action)
                    {
                    if (chmod (file,newperm & 07777) == -1)
 		      {
-                      sprintf("chmod failed on %s\n",file);
+                      sprintf(OUTPUT,"chmod failed on %s\n",file);
                       CfLog(cferror,OUTPUT,"chmod");
                       break;
 		      }
@@ -528,16 +528,30 @@ struct Item *acl_aliases;
 
 { mode_t newplus,newminus;
 
-if ((plus == 0) && (minus == 0))
-   {
-   newplus = sstat->st_mode & 07777;
-   newminus = ~(sstat->st_mode & 07777) & 07777;
-   CheckExistingFile(file,newplus,newminus,fixall,uidlist,gidlist,dstat,NULL,acl_aliases);
-   }
-else
-   {
-   CheckExistingFile(file,plus,minus,fixall,uidlist,gidlist,dstat,NULL,acl_aliases);
-   }
+ /* plus/minus must be relative to source file, not to
+    perms of newly created file!
+
+
+! if ((plus == 0) && (minus == 0))
+     {
+!    newplus = sstat->st_mode & 07777;
+!    newminus = ~(sstat->st_mode & 07777) & 07777;
+     CheckExistingFile(file,newplus,newminus,fixall,uidlist,gidlist,dstat,NULL,acl_aliases);
+     }
+
+ */
+
+ if (true)
+    {
+    newplus = sstat->st_mode & 07777 | plus;
+    newminus = ~(sstat->st_mode & 07777 & ~minus) & 07777;
+    Debug2("CheckCopiedFile: %s: +%o, -%o\n",file,newplus,newminus);
+    CheckExistingFile(file,newplus,newminus,fixall,uidlist,gidlist,dstat,NULL,acl_aliases);
+    }
+ else
+    {
+    CheckExistingFile(file,plus,minus,fixall,uidlist,gidlist,dstat,NULL,acl_aliases);
+    }
 }
 
 /*********************************************************************/
@@ -792,9 +806,14 @@ char *pathto, *name;
 
 { struct Item *ip;
 
+if (name == NULL || strlen(name) == 0)
+   {
+   return false;
+   }
+ 
 strcpy(VBUFF,pathto);
 AddSlash(VBUFF);
-strcat(VBUFF,name);
+strcat(VBUFF,name); 
 
 for (ip = VIGNORE; ip != NULL; ip=ip->next)
    {
