@@ -223,7 +223,7 @@ char OUTPUT[bufsize*2];
  PROTECTED char       VFQNAME[maxvarsize];
  PROTECTED char       VUQNAME[maxvarsize];
  PROTECTED char       LOGFILE[maxvarsize];
-
+ PROTECTED char         VYEAR[5];
 
  /*******************************************************************/
  /* Command line options                                            */
@@ -638,6 +638,7 @@ char OUTPUT[bufsize*2];
      "AppendToLineIfNotContains",
      "DeleteLinesAfterThisMatching",
      "DefineClasses",
+     "CatchAbort",
      NULL
      };
 
@@ -696,6 +697,7 @@ char OUTPUT[bufsize*2];
   PRIVATE unsigned short PORTNUMBER = 0;
   PRIVATE char VIPADDRESS[18];
   PRIVATE char CFSERVER[maxvarsize];
+  PRIVATE int  CF_TIMEOUT = 10;
 
 /*******************************************************************/
 /*                                                                 */
