@@ -98,6 +98,11 @@ for (dirp = cfreaddir(dirh,ip); dirp != NULL; dirp = cfreaddir(dirh,ip))
       continue;
       }
 
+   if (ip->purge == 'y') /* Do not purge this file */
+      {
+      AppendItem(&namecache,dirp->d_name,NULL);
+      }
+
    if (IgnoreFile(from,dirp->d_name))
       {
       continue;
@@ -107,11 +112,6 @@ for (dirp = cfreaddir(dirh,ip); dirp != NULL; dirp = cfreaddir(dirh,ip))
       {
       continue;
       }
-
-   if (ip->purge == 'y')
-      {
-      AppendItem(&namecache,dirp->d_name,NULL);
-      }
    
    strcpy(newfrom,from);                                   /* Assemble pathname */
    AddSlash(newfrom);
@@ -565,6 +565,7 @@ if (lstat(destfile,&deststatbuf) == -1)
 
       if (CopyReg(sourcefile,destfile,sourcestatbuf,deststatbuf,ip))
          {
+	 stat(destfile,&deststatbuf);
          CheckCopiedFile(destfile,ip->plus,ip->minus,fixall,ip->uid,ip->gid,&deststatbuf,&sourcestatbuf,NULL,ip->acl_aliases);
 	 AddCopyClasses(ip);
          }
@@ -772,7 +773,7 @@ else
             return;
             }
 
-         sprintf(OUTPUT,"Checkinging link from %s to %s\n",destfile,linkbuf);
+         sprintf(OUTPUT,"Checking link from %s to %s\n",destfile,linkbuf);
 	 CfLog(cfverbose,OUTPUT,"");
 
          LinkFiles(destfile,linkbuf,NULL,NULL,NULL,0,&empty);
