@@ -1142,7 +1142,7 @@ char *from, *to;
 { struct Link *ptr;
   char buffer[bufsize], buffer2[bufsize];
   
-Debug1("Storing Link: %s -> %s\n",from,to);
+Debug1("Storing Link: (From)%s->(To)%s\n",from,to);
 
 if ( ! IsInstallable(CLASSBUFF))
    {
@@ -1158,7 +1158,7 @@ ExpandVarstring(to,buffer,"");
 
 bzero(buffer2,bufsize);
 ExpandVarstring(ALLCLASSBUFFER,buffer2,""); 
-
+ 
 if ((ptr = (struct Link *)malloc(sizeof(struct Link))) == NULL)
    {
    FatalError("Memory Allocation failed for InstallListItem() #1");
@@ -2250,6 +2250,8 @@ switch (units)
              break;
    case 'm': IMGSIZE = i * 1024;
              break;
+   case '%': IMGSIZE = -i;       /* -ve number signals percentage */
+             break;
    default:  IMGSIZE = i;
    }
 }
@@ -2311,15 +2313,21 @@ HandleTidyRmdirs(value)
 char *value;
 
 {
-if (strcmp(value,"true") == 0)
+if ((strcmp(value,"true") == 0)||(strcmp(value,"all") == 0))
    {
-   TIDYDIRS = true;
+   TIDYDIRS = 1;
    return;
    }
 
-if (strcmp(value,"false") == 0)
+if ((strcmp(value,"false") == 0)||(strcmp(value,"none") == 0))
    {
-   TIDYDIRS = false;
+   TIDYDIRS = 0;
+   return;
+   }
+
+if (strcmp(value,"sub") == 0)
+   {
+   TIDYDIRS = 2;
    return;
    }
 
@@ -3013,9 +3021,9 @@ switch (*value)
 
 sscanf(value,"%d",&i);
 
-if ((i < 1) || ((value == 0) && (PROCOMP == '=')))
+if (i < 0) 
    {
-   yyerror("matches attribute with silly value (must be > 0)");
+   yyerror("matches attribute with silly value (must be >= 0)");
    }
 
 PROMATCHES = (short) i;
@@ -3251,9 +3259,10 @@ for (sp = value; *sp != '\0'; sp++)
       continue;
       }
    
-   if (! isalnum(*sp))
+   if (! isalnum(*sp) && *sp != '_')
       {
-      yyerror("illegal class list in define=");
+      sprintf(OUTPUT,"Illegal class list in define=%s\n",value);
+      yyerror(OUTPUT);
       }
    }
 }
@@ -3784,13 +3793,15 @@ tp->pattern = sp;
 tp->next = *list;
 tp->dirlinks = ldirs;
 
-if (tidydirs)
+switch (tidydirs)
    {
-   tp->rmdirs = 't';
-   }
-else
-   {
-   tp->rmdirs = 'f';
+   case 0: tp->rmdirs = 'f';
+           break;
+   case 1: tp->rmdirs = 't';
+           break;
+   case 2: tp->rmdirs = 's';
+           break;
+   default: FatalError("Software error in Prepend Tidy");
    }
 
 *list = tp;
