@@ -458,9 +458,11 @@ if (IsWildItemIn(VCOPYLINKS,lastnode) || IsWildItemIn(copy,lastnode))
    ip.inclusions = NULL;
    ip.symlink = NULL;
    ip.classes = NULL;
+   ip.server = strdup("localhost");
    Verbose("%s: Link item %s marked for copying instead\n",VPREFIX,from);
    MakeDirectoriesFor(to);
    CheckImage(to,from,&ip);
+   free(ip.server);
    return true;
    }
 
@@ -493,9 +495,9 @@ if (lstat(from,&buf) == 0)
    {
    if (! S_ISLNK(buf.st_mode) && ! ENFORCELINKS)
       {
-      Silent(OUTPUT,"Error linking %s -> %s\n",from,to);
+      sprintf(OUTPUT,"Error linking %s -> %s\n",from,to);
       CfLog(cfsilent,OUTPUT,"");
-      Silent(OUTPUT,"Cannot make link: %s exists and is not a link! (uid %d)\n",from,buf.st_uid);
+      sprintf(OUTPUT,"Cannot make link: %s exists and is not a link! (uid %d)\n",from,buf.st_uid);
       CfLog(cfsilent,OUTPUT,"");
       return(true);
       }
