@@ -40,7 +40,7 @@ TimeOut()
  
 {
 alarm(0);
-Verbose("cfengine: Time out\n");
+Verbose("%s: Time out\n",VPREFIX);
 }
  
 /*************************************************************************/
