@@ -62,7 +62,7 @@ ParseInputFiles()
   char filename[bufsize], *sp;
   void TimeOut();
 
-if (strcmp(VINPUTFILE,".") == 0) /* read from standard input */
+if ((strcmp(VINPUTFILE,".") == 0)||(strcmp(VINPUTFILE,"-") == 0)) /* read from standard input */
    {
    yyin = stdin;
 
@@ -375,7 +375,7 @@ if (item[0] == '+')                               /* Lookup in NIS */
       FatalError("Netgroups may only define internal groups or illegal octal file action.");
       }
    }
-else if (item[0] == '-') 
+else if ((item[0] == '-') && (ACTION != processes))
    {
    item++;
 
@@ -401,8 +401,11 @@ else if (item[0] == '-')
          }
       else
          {
-         yyerror("Illegal deletion sign or octal number");
-         FatalError("The deletion operator may only be in the groups: action");
+	 if (ACTION != processes)
+	    {
+	    yyerror("Illegal deletion sign or octal number?");
+	    FatalError("The deletion operator may only be in the groups: action");
+	    }
          }
       }
 
@@ -509,6 +512,7 @@ else
       
                         if (strcmp(item,"SetOptionString") == 0)
 			   {
+			   Debug("Found SetOptionString\n");
                            if (EXPR[0] == '\0')
 			      {
    			      strcpy(EXPR,item);
@@ -543,8 +547,7 @@ else
 			   }
                         break;
 
-      default:          printf("cfengine:%s: Internal software failure: Unknown action (%s)\n",VPREFIX,item);
-	                FatalError("Stopped");
+      default:          yyerror("Unknown item or out of context");
       }
    }
 }
@@ -701,9 +704,7 @@ else
 			   }
 		       break;
 
-      default:         printf ("HandlePath() DEFAULT\n");
-                       printf ("Fatal action is %s\n",ACTIONTEXT[ACTION]);
-                       FatalError("Internal software error in HandlePath()");
+      default:         yyerror("Unknown command or name out of context");
       }
    }
 }
@@ -726,7 +727,7 @@ Debug1("HandleVarpath(%s)\n",varpath);
 
 if (IsWildCard(varpath) && ! (ACTION == files || ACTION == tidy || ACTION == admit || ACTION == deny))
    {
-   yyerror("Wildcards cannot be used in this context:");
+   yyerror("Wildcards cannot be used in this context (possibly missing space?)");
    }
 
 strcpy(CURRENTPATH,varpath);
@@ -841,7 +842,9 @@ else
 	                strcpy(CURRENTAUTHPATH,varpath);
 	                break;
 
-      default:          FatalError("software error in HandleVarpath()");
+      case groups:      yyerror("Variables in groups/classes need to be quoted");
+
+      default:          yyerror("Variable or name out of context");
       }
    }
 }
@@ -1024,7 +1027,6 @@ else                                    /* parent */
       {
       printf("%s: Wait for child failed\n",VPREFIX);
       perror("wait");
-      free(argv);
       return false;
       }
    else
@@ -1032,30 +1034,25 @@ else                                    /* parent */
       if (WIFSIGNALED(status))
          {
          Debug("%s: script %s returned: %d\n",VPREFIX,comm,WTERMSIG(status));
-	 free(argv);
          return false;
          }
 
       if (! WIFEXITED(status))
          {
-	 free(argv);
          return false;
          }
 
       if (WEXITSTATUS(status) == 0)
          {
-	 free(argv);
          return true;
          }
       else
          {
-	 free(argv);
          return false;
          }
       }
    }
 
-free(argv);
 return false;
 }
 
