@@ -48,6 +48,8 @@ char *psopts;
   char pscomm[maxlinksize];
 
 sprintf(pscomm,"%s %s",VPSCOMM[VSYSTEMHARDCLASS],psopts);
+
+Verbose("%s: Running process command %s\n",VPREFIX,pscomm); 
   
 if ((pp = cfpopen(pscomm,"r")) == NULL)
    {
@@ -189,21 +191,21 @@ if (pp->matches >= 0)
       case '=': if (matches != (int)pp->matches)
                    {
 	    	   sprintf(OUTPUT,"%d processes matched %s (should be %d)\n",matches,pp->expr,pp->matches);
-		   CfLog(cfinform,OUTPUT,"");
+		   CfLog(cferror,OUTPUT,"");
 		   }
                 break;
 		
-      case '>': if (matches <= (int)pp->matches)
+      case '>': if (matches < (int)pp->matches)
 	           {
-	    	   sprintf(OUTPUT,"%d processes matched %s (should be >%d)\n",matches,pp->expr,pp->matches);
-		   CfLog(cfinform,OUTPUT,"");
+	    	   sprintf(OUTPUT,"%d processes matched %s (should be >=%d)\n",matches,pp->expr,pp->matches);
+		   CfLog(cferror,OUTPUT,"");
 	           } 
                 break;
 		
-      case '<': if (matches >= (int)pp->matches)
+      case '<': if (matches > (int)pp->matches)
 	           {
-	    	   sprintf(OUTPUT,"%d processes matched %s (should be <%d)\n",matches,pp->expr,pp->matches);
-		   CfLog(cfinform,OUTPUT,"");
+	    	   sprintf(OUTPUT,"%d processes matched %s (should be <=%d)\n",matches,pp->expr,pp->matches);
+		   CfLog(cferror,OUTPUT,"");
 	           } 
       }
    }
@@ -212,7 +214,7 @@ if (strlen(pp->restart) != 0)
    {
    if ((matches != 0) && (pp->signal != cfkill) && (pp->signal != cfterm))
       {
-      Verbose("Matches found for %s - no restart sequence\n",pp->expr);
+      Verbose("%s: Matches found for %s - no restart sequence\n",VPREFIX,pp->expr);
       return;
       }
 
@@ -269,7 +271,7 @@ if (strlen(pp->restart) != 0)
 	 break;
 	 }
       
-      sprintf("Restart: %s",line);
+      sprintf(OUTPUT,"Restart: %s",line);
       CfLog(cfinform,OUTPUT,"");
       }
 
